> Hotel >
<TABLE width="500px" height="500px" border="0" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD>
Hotel ANDALUZIA *** din Giurgiu dispune de urmatoarele :<br>
- Fiecare camera are urmatoarele dotari:<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Acces cu cartela<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Aer conditionat<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- TV cu cablu TV<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Minibar<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Uscator de par in baie<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Internet<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Telefon<br>
<br>
- Ziua hoteliera incepe la ora 12.00 <br>
- Ziua hoteliera se termina la 12.00 <br>
- Programul de functionare este NON-STOP<br>
	</TD>
</TR>
</TABLE>
<div id="divWG">
<table id="tblThumbsLayout" cellpadding="0" cellspacing="5">
<tr>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-01.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant ***" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-01.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-02.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-02.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-03.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-03.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-04.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-04.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-05.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-05.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-06.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-06.JPG"></a><br></td>
</tr>
<tr>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-07.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-07.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-08.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-08.JPG"></a><br></td>

<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-09.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-09.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-10.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-10.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-11.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-11.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-12.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-12.JPG"></a><br></td>
</tr>
<tr>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-13.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-13.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-14.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-14.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-15.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-15.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-16.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-16.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-17.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-17.JPG"></a><br></td>
<td class="tdImg"><a href="img/galerie/hotel/hotel-restaurant-giurgiu-18.JPG" rel="lightbox[gallery]"><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-18.JPG"></a><br></td>
</tr>
</table>
</div>

<CENTER>Va multumim ca ati ales sa colaborati cu noi si va asteptam!!!	</CENTER>