> Reservations >
<TABLE width="500px" border="0" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD><br>
<CENTER><H4>Online Reservation</H4></CENTER>
The accomodation day :<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; - Start at : 12.00 o'clock p.m.<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; - Finish at : 12.00 o'clock p.m. ( at noon )<br>
- The Daily program : NON-STOP<br>
<br><br>
<TABLE border="0">
	<form action='sendmail1.php' method='post'>
		<TR><TD>Name and Surname : </TD><TD><input type=text name=nume ><BR></TD></TR>
		<TR><TD>Town / City : </TD><TD><input type=text name=oras ><BR></TD></TR>
		<TR><TD>E-mail adress : </TD><TD><input type=text name=email ><BR></TD></TR>
		<TR><TD>Telephon Number: </TD><TD><input type=text name=telefon ><BR></TD></TR>
		<TR><TD>Check-in date : </TD><TD><input type=text name=rezervare ><BR></TD></TR>
		<TR><TD>Check-out date : </TD><TD><input type=text name=zile ><BR></TD></TR>
		<TR><TD>Number of people : </TD><TD><input type=text name=persoane ><BR></TD></TR>
		<TR><TD>Number of rooms : </TD><TD><input type=text name=camere ><BR></TD></TR>		
		<tr><td class="form_field" valign='top' >Observations :</td><td class="form_text"><textarea name="obs" rows=6 cols=28 ></textarea>
		</td> 
	</tr> 
		<TR><TD colspan="2" ><CENTER>All fields are required !</CENTER></TD></TR>
		<TR><TD colspan="2" ><CENTER><input type=submit name=submit value='Send reservation'></CENTER></TD>
		</TR>
	</form>
</TABLE>
<center>Thank you for choosing to collaborate with us and we're waiting you!</center>
	</TD>
</TR>
</TABLE>