<CENTER>
<?php echo file_get_contents("http://www.avicolauzunu.ro/footer_parteneri.php"); ?>
<!-- script statistics.ro : V2 : html-easy -->
<script type="text/javascript" src="http://hitx.statistics.ro/hitx2.js"></script>
<a href="http://www.wta.ro/5800stats_index" target="_blank" title="Statistici web"><script type="text/javascript">
st_ro_start(5800, "", "", "");</script></a>
<noscript><a href="http://www.wta.ro/"><img src="http://hitx.statistics.ro/5800/1/-/-/-/a-x/nojs.gif" width="88" height="31" alt="Statistici web"></a></noscript>
<!-- end of script statistics.ro : V2 : html-easy -->
</CENTER>