> Restaurant >
<TABLE width="500px" border="0" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD>
 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;ANDALUZIA Restaurant *** din Giurgiu has a :<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Restaurant - capacity 380 places<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Terrace - capacity 45 places<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Breakfast ( between : 07.30 - 10.00 )<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Romanian traditional meals <br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- The Restaurant and The terrace also features :<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Air conditioner ( in the Restaurant )<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- TV set ( in the Restaurant , on the Terrace )<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Internet ( in the Restaurant , on the Terrace )<br>
 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;The Daily Programme ( 08.00 a.m. - 12.00 at night )<br>
	</TD>
</TR>
</TABLE>
<div id='divWG'>
<table id="tblThumbsLayout" cellpadding="0" cellspacing="5">
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-01.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant ***" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-01.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-02.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-02.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-03.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-03.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-04.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-04.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-05.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-05.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-06.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-06.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-07.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-07.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-08.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-08.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-09.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-09.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-10.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-10.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-11.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-11.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-12.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-12.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-13.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-13.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-14.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-14.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-15.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-15.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-16.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-16.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-17.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-17.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-18.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-18.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-19.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-19.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-20.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-20.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-21.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-21.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-22.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-22.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-23.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-23.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-24.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-24.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-25.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-25.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-26.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-26.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-27.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-27.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-28.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-28.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-29.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-29.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-30.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-30.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
</table>
</div>
<center>Thank you for choosing to collaborate with us and we're waiting you!</center>