<center>Va asteptam cu drag sa petrecem impreuna la cumpana dintre ani .</center>
<br>
<img width="600px"  height="272px" src="img/revelion-andaluzia-2010-fata-600x272.png" />
<br>
<img width="600px"  height="272px" src="img/revelion-andaluzia-2010-verso-600x274.png" />
<br>
<center>Rezervarile se fac ONLINE sau TELEFONIC<br>In limita locurilor disponibile</center>