<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<HTML>
 <HEAD>
<TITLE>Cazare - Hotel - Restaurant ANDALUZIA *** - Giurgiu, cazare giurgiu, Hotel Andaluzia, restaurant, tranzit, bulgaria, ruse, rouse</TITLE>
<meta name="generator" content="Notepad++">
<meta name="author" content="stefanfloringr@gmail.com - 0721076336">
<META NAME="Keywords" CONTENT="Cazare, Hotel, Restaurant, ANDALUZIA, Giurgiu, cazare giurgiu, tranzit, bulgaria, ruse, rouse ">
<META NAME="Description" CONTENT="Cazare, Hotel, Restaurant, ANDALUZIA, Giurgiu, cazare giurgiu, tranzit, bulgaria, ruse, rouse" >
<meta http-equiv="Content-Type" content="text/html;charset=utf-8" >
<link rel="stylesheet" href="css/hotelrestaurantgiurgiu.css"  type="text/css" media="screen" >
<meta name="google-site-verification" content="IehQmyTlG3AzIe2Pe34xw4_rmR-ejkZW18uoSnCVuvY" >
<script src="lightbox/js/prototype.js" type="text/javascript"></script>
<script src="lightbox/js/scriptaculous.js?load=effects" type="text/javascript"></script>
<script src="lightbox/js/lightbox.js" type="text/javascript"></script>
 </HEAD>
<body>
<a href="pub/meniu-livrari-la-domiciliu-restaurant-andaluzia-giurgiu.pdf" target="_blank"><img id="img_reclama" src="img/livrari-la-domiciliu-restaurant-andaluzia-giurgiu-1.jpg" alt="meniu livrari la domiciliu hotel restaurant andaluzia giurgiu"></a>
 <div id="all"> 
 <div id="continut">
 <div id="menu"><?php include_once("menu.php"); ?></div>
 <div id="materiale"><?php include_once("dinamic.php"); ?></div>
</div></div>
<?php include_once("footer.php"); ?>

</body>
</HTML>
