body {
background-color : #7d0207;
font-family : Georgia, Verdana, Arial;
font-size : 12pt;
color : #7d0207;
}
div#all {
width : 1246px;
height : 1052px;
margin : 0 auto;
background-color : #7d0207;
background-image : url(/img/fundal.jpg);
background-repeat : no-repeat;
background-position : center top;
}
div#revelion {
width : 600px;
height : 90px;
position : relative;
left : 26px;
top : 120px;
}
div#menu {
width : 110px;
height : 40px;
position : relative;
left : 26px;
top : 180px;
}
div#continut {
width : 1246px;
height : 1100px;
border : thin solid #ffffff;
}
div#footer {
width : 1246px;
text-align: center;
color : #ffffff;
border : thin solid #ffffff;
}
div#materiale {
width : 600px;
position : relative;
left : 24px;
top : 210px;
padding : 0.5em;
margin : 5px;
color : #7d0207;
border : thin solid #7d0207;
background-color : #fadda8;
}
#img_reclama{
width: 622px; 
position: absolute; 
margin-top: 5px; 
margin-left: 28px;
}
a:link {
text-decoration : none;
color : #ffffff;
}
a:visited {
text-decoration : none;
color : #ffffff;
}
a:hover {
text-decoration : none;
color : #ffffff;
}
a:active {
text-decoration : none;
color : #ffffff;
}
#lightbox {
position : absolute;
top : 40px;
left : 0;
width : 100%;
z-index : 100;
text-align : center;
line-height : 0;
}
#lightbox a img {
border : none;
}
#outerImageContainer {
position : relative;
background-color : #fff;
width : 250px;
height : 250px;
margin : 0 auto;
}
#imageContainer {
padding : 10px;
}
#loading {
position : absolute;
top : 40%;
left : 0%;
height : 25%;
width : 100%;
text-align : center;
line-height : 0;
}
#hoverNav {
position : absolute;
top : 0;
left : 0;
height : 100%;
width : 100%;
z-index : 10;
}
#imageContainer > #hoverNav {
left : 0;
}
#hoverNav a {
outline : none;
}
#prevLink, #nextLink {
width : 49%;
height : 100%;
background : transparent url(../images/blank.gif) no-repeat;
display : block;
}
#prevLink {
left : 0;
float : left;
}
#nextLink {
right : 0;
float : right;
}
#prevLink:hover, #prevLink:visited:hover {
background : url(../images/prevlabel.gif) no-repeat left 15%;
}
#nextLink:hover, #nextLink:visited:hover {
background : url(../images/nextlabel.gif) no-repeat right 15%;
}
#imageDataContainer {
font : 10px Verdana, Helvetica, sans-serif;
background-color : #fff;
margin : 0 auto;
line-height : 1.4em;
}
#imageData {
padding : 0 10px;
}
#imageData #imageDetails {
width : 70%;
float : left;
text-align : left;
}
#imageData #caption {
font-weight : bold;
}
#imageData #numberDisplay {
display : block;
clear : left;
padding-bottom : 1em;
}
#imageData #bottomNavClose {
width : 66px;
float : right;
padding-bottom : 0.7em;
}
#overlay {
position : absolute;
top : 0;
left : 0;
z-index : 90;
width : 100%;
height : 500px;
background-color : #000000;
}
.clearfix:after {
content : ".";
display : block;
height : 0;
clear : both;
visibility : hidden;
}
* html > body .clearfix {
display : inline-block;
width : 100%;
}
* html .clearfix {
height : 1%;
}
#prevLink {
background : url(../lightbox/images/prevlabel.gif) no-repeat left 15%;
}
#nextLink {
background : url(../lightbox/images/nextlabel.gif) no-repeat right 15%;
}
body #divWG {
text-align : center;
font : 11px Verdana, Arial, Helvetica, sans-serif;
}
#divWG img, #divWG table {
border : none;
}
#divWG a:link, #divWG a:visited {
text-decoration : none;
}
#divWG a:hover {
color : red;
text-decoration : underline;
}
#tblThumbsLayout {
text-align : left;
margin : 0 auto;
}
#tblGalleryName {
margin-top : 2px;
}
#currentGalleryLocation {
font-weight : bold;
}
td#galleryNameCell {
font-size : 18px;
font-weight : bold;
color : #606060;
margin : 6px 6px 0 0;
}
td#pagingCell {
text-align : right;
white-space : nowrap;
}
.currentPage {
font-weight : bold;
}
td#pagingCell a, .currentPage {
font-size : 12px;
border : 1px solid #ccc;
vertical-align : middle;
}
td#pagingCell a:hover, .currentPage {
border : 1px solid #666;
background-color : #fff;
text-decoration : none;
}
td.tdImg {
border : 2px solid;
border-color : #7d0207;
text-align : center;
vertical-align : middle;
}
td.tdImg img {
margin-top : 0;
}
#pnCell {
text-align : right;
}
a.pn, a.pn:link, a.pn:visited {
color : #606060;
font : 9px arial, helvetica, sans-serif;
text-decoration : none;
}
