<?
####################################################################################
$to = "office@hotelrestaurantgiurgiu.ro";

if(($_POST['name']!="")&&($_POST['email']!="")&&($_POST['phone']!="")&&($_POST['oras']!="")&&($_POST['detalii']!="")){

	####### dont edit the code after this line! ###################################
	$subject = 'Email de la site';
	$from = $_POST['email'];
	$content = "<B>Nume si prenume:</B>&nbsp;&nbsp;" . $_POST['name'] ."<br><B>Email:</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['email'] ."<br><B>Telefon:</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['phone'] ."<br><B>Oras:</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['oras'] ."<BR><BR><B>Detalii :</B>&nbsp;&nbsp;" . $_POST['detalii'] ;

	mail($to , $subject, $content, "From: $from \n" ."MIME-Version: 1.0\n" . "Content-type: text/html; charset=iso-8859-1");
	echo "<script>alert('Email trimis . Va multumim !')</script>";
}
else{
	echo "<script>alert('Email esuat ! Mesajul nu este complet !')</script>";
}
echo "<script>location.replace('index.php?hotel_restaurant=contact')</script>";
?>