> Hotel >
<TABLE width="500px" border="0" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;ANDALUZIA Hotel *** from Giurgiu offers :<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;( Every room also features )<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Personal card acces<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Air - conditioner<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- TV set<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Minibar<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Hairdrayer<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Internet<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Telephone<br>
<br>
- The accomodation day in our hotel starts at 12:00 o'clock P.M. and finish at the 12:00 o'clock ( at noon )<br>
- Daily program : NON-STOP<br>
	</TD>
</TR>
</TABLE>
<div id='divWG'>
<table id="tblThumbsLayout" cellpadding="0" cellspacing="5">
<tr>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-01.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant ***" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-01.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-02.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-02.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-03.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-03.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-04.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-04.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-05.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-05.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-06.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-06.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-07.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-07.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-08.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-08.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>

<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-09.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-09.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-10.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-10.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-11.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-11.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-12.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-12.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-13.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-13.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-14.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-14.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-15.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-15.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-16.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-16.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-17.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-17.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
<td class='tdImg'><a href='img/galerie/hotel/hotel-restaurant-giurgiu-18.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/hotel/hotel-restaurant-giurgiu-18.JPG" alt="Complex Andaluzia - Hotel - Restaurant *** Giurgiu"></a><br></td>
</tr>
</table>
</div>
<center>Thank you for choosing to collaborate with us and we're waiting you!</center>