> Acasa >
<TABLE style="width:500px; height:500px;" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Complexul Hotel - Restaurant ANDALUZIA se afla situat pe partea dreapta a DN 5 pe sensul de mers BUCURESTI - GIURGIU km 59+420, este locul ideal unde se pot petrece clipe minunate si unde poti obtine odihna necesara cand va aflati zona de sud a tari.  <br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Giurgiu este resedinta si cel mai mare oras al judetului Giurgiu, Muntenia, Romania. Este un port fluvial important si un punct de frontiera cu Bulgaria.<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;El se situeaza in extremitatea sudica a Romaniei ,pe malul stang al Dunarii, la 65 km sud de capitala Bucuresti, formand o Euroregiune cu orasul vecin, bulgar, Ruse (Pyce).<br>
<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Obiective ce merita vizitate:<br>
- Turnul cu ceas<br>
- Podul Bizetz - primul pod in curba din Europa<br>
- Parcul Alei<br>
- Parcul Mihai Viteazul<br>
- Portul Ramadan<br>
- Ruinele cetatii Giurgiului<br>
- Strada Garii, strada cu numeroase cladiri istorice<br>
- Teatrul Valah<br>
- Ateneul Nicolae Balanescu<br>
- Catedralei Adormirea Maicii Domnului<br>
- Schitul Acoperamantul Maicii Domnului<br>
- Schitului Barbu Belu<br>
- Manastirea Comana<br>
- Manastirea Delta Neajlovului<br>
- Schitului Sfantul Ioan Rusul<br>
- Schitului Sfantul Nicolae<br>
- Manastirea Sfantul Gheorghe<br>
	</TD>
</TR>
</TABLE>
<br>
<CENTER>Va multumim ca ati ales sa colaborati cu noi si va asteptam!!!	</CENTER>
