> Home >
<TABLE width="500px" border="0" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Andaluzia , The Complex Hotel - Restaurant there is situated on the right road Bucharest - Giurgiu , km 59+420.
<br>
It is the perfect place where you can spend fantastic moments and you can rest when you are in the south of the country .  <br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Giurgiu is a capital-city and it is the biggest town of Giurgiu , Muntenia zone , Romania.
<br>
It is an important fluvial harbour at the frontier with Bulgaria.
<br>
It is situated in the extreme south side of Romania , on the left bank of the Danube , 65 km far away of Bucharest , the capital of Romania , facing the Bulgarian city of Rousse on the opposite bank ( Pyce ).
<br>
<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Touristic places you can visit :
<br>
<br>
- The Clock Tower ( in the middle of the town )<br>
- The Bizetz Bridge ( the first curve bridge in Europe )<br>
- The Alei Park<br>
- Mihai Viteazul Park<br>
- The Ramadan Harbour<br>
- The Ruineof Giurgiu fortress<br>
- The Station Street ( has got numerous ancient buildings )<br>
- Theatre Valah<br>
- Nicolae Balanescu Atheneum<br>
- The Cathedral<br>
- The Virgin Mother Hermitage<br>
- Barbu Belu Hermitage<br>
- The Comana Monastery<br>
- The Delta Neajlovului Monastery<br>
- St. John the Russian Hermitage<br>
- St. Nicolas Hermitage<br>
- St. Gheorghe Monastery<br>
	</TD>
</TR>
</TABLE>
<br>
<center>Thank you for choosing to collaborate with us and we're waiting you!</center>
