> Rezervari >
<TABLE width="500px" border="0" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD><br>
<CENTER><H4>Rezerva camere online</H4></CENTER>
- Ziua hoteliera incepe la ora 12.00 <br>
- Ziua hoteliera se termina la 12.00 <br>
- Programul de functionare este NON-STOP<br>
<br><br>
<form action='sendmail1.php' method='post'>
<TABLE border="0">
		<TR><TD>Nume si prenume : </TD><TD><input type=text name="nume" size="36" ><BR></TD></TR>
		<TR><TD>Oras : </TD><TD><input type=text name="oras" size="36"><BR></TD></TR>
		<TR><TD>Adresa de email : </TD><TD><input type=text name="email" size="36" ><BR></TD></TR>
		<TR><TD>Nr telefon : </TD><TD><input type=text name="telefon" size="36" ><BR></TD></TR>
		<TR><TD>Reverv de la data : </TD><TD><input type=text name="rezervare" size="36" ><BR></TD></TR>
		<TR><TD>Nr zile rezervate : </TD><TD><input type=text name="zile" size="36" ><BR></TD></TR>
		<TR><TD>Nr persoane : </TD><TD><input type=text name="persoane" size="36" ><BR></TD></TR>
		<TR><TD>Nr camere : </TD><TD><input type=text name="camere" size="36" ><BR></TD></TR>		
		<tr><td class="form_field" valign='top' >Observatii :</td><td class="form_text"><textarea name="obs" rows=6 cols=28 ></textarea>
		</td> 
	</tr> 
		<TR><TD colspan="2" ><CENTER>Toate campurile sunt obligatorii !</CENTER></TD></TR>
		<TR><TD colspan="2" ><CENTER><input type=submit name="submit" value='Trimite Email'></CENTER></TD>
		</TR>
</TABLE>
</form>
<CENTER>Va multumim ca ati ales sa colaborati cu noi si va asteptam!!!	</CENTER>
	</TD>
</TR>
</TABLE>