<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<HTML>
 <HEAD>
<TITLE>Hotel Giurgiu, Hotel - Restaurant ANDALUZIA ***, restaurant giurgiu, hoteluri giurgiu, giurgiu hotel, cazare giurgiu, Hotel Andaluzia, restaurant, hotel, cazare, andaluzia, giurgiu, bulgaria</TITLE>
<meta name="generator" content="Notepad++">
<meta name="author" content="stefanfloringr@gmail.com - 0721076336">
<META NAME="Keywords" CONTENT="Hotel Giurgiu, Hotel - Restaurant ANDALUZIA ***, restaurant giurgiu, hoteluri, giurgiu hotel, giurgiu, cazare giurgiu, Hotel Andaluzia, restaurant, hotel, cazare, andaluzia, giurgiu, bulgaria" >
<META NAME="Description" CONTENT="Hotel Giurgiu, Hotel - Restaurant ANDALUZIA ***, restaurant giurgiu, hoteluri giurgiu, giurgiu hotel, cazare giurgiu, Hotel Andaluzia, restaurant, hotel, cazare, andaluzia, giurgiu, bulgaria" >
<meta http-equiv="Content-Type" content="text/html;charset=utf-8" >
<link rel="stylesheet" href="css/hotelrestaurantgiurgiu.css"  type="text/css" media="screen" >
<meta name="google-site-verification" content="IehQmyTlG3AzIe2Pe34xw4_rmR-ejkZW18uoSnCVuvY" >
<script src="lightbox/js/prototype.js" type="text/javascript"></script>
<script src="lightbox/js/scriptaculous.js?load=effects" type="text/javascript"></script>
<script src="lightbox/js/lightbox.js" type="text/javascript"></script>
 </HEAD>
<body style=alink="#ffffff" link="#ffffff" vlink="#ffffff">
  <div id="all">
 <div id="continut">
 <div id="menu"><?php include_once("menu.php"); ?></div>
 <div id="materiale"><?php include_once("dinamic.php"); ?></div>
</div>
<div id="footer"><?php include_once("../footer.php"); ?></div>
</div>
 </BODY>
</HTML>
