body
	{
	background-color: #7d0207;
	font-family: Georgia, Verdana, Arial;
	font-size: 12pt;
	color: #7d0207; 
	}
div#all 
	{
	width: 1246px;
	height: 1052px;
	margin: 0px auto;
	background-color: #7d0207;
	background-image: url(/img/fundal.jpg);
	background-repeat:  no-repeat;
	background-position: top center;
	}
div#menu 
	{
	width: 110px;
	height: 40px;
	position: relative; 
	left: 26px; 
	top: 180px;
}
div#continut 
	{
	width: 1246px;
	height: 1052px;
	border: solid thin #ffffff;
	-webkit-border-radius: .1em;
	-moz-border-radius: .1em;
	border-radius: .1em;
	-webkit-box-shadow: 8px 8px 8px #999999; 
	box-shadow: 8px 8px 8px #bbbbbb;
}
div#footer 
	{
	width: 1246px;
	color: #ffffff;
	text-shadow: 0px 0px 0px #000000;
	border: solid thin #ffffff;
	-webkit-border-radius: .1em;
	-moz-border-radius: .1em;
	border-radius: .1em;
	-webkit-box-shadow: 8px 8px 8px #999999; 
	box-shadow: 8px 8px 8px #bbbbbb;
}
div#materiale
	{
	width: 600px;
	position: relative; 
	left: 24px; 
	top: 210px;
	padding: .5em;
	margin: 5px;
	color: #7d0207;
	text-shadow: 1px 1px 1px #bbbbbb;
	border: solid thin #7d0207;
	-webkit-border-radius: .1em;
	-moz-border-radius: .1em;
	border-radius: .1em;
	-webkit-box-shadow: 8px 8px 8px #999999; 
	box-shadow: 8px 8px 8px #bbbbbb;
	background-color: #fadda8;
	}

a:link
	{
	text-decoration: none;
	color: #ffffff;
	}
a:visited 
	{
	text-decoration: none;
	color: #ffffff;
	}
a:hover 
	{
	text-decoration: none;
	color: #ffffff;
	}
a:active 
	{
	text-decoration: none;
	color: #ffffff;
	}

#lightbox{
	position: absolute;
	top: 40px;
	left: 0;
	width: 100%;
	z-index: 100;
	text-align: center;
	line-height: 0;
	}

#lightbox a img{ border: none; }

#outerImageContainer{
	position: relative;
	background-color: #fff;
	width: 250px;
	height: 250px;
	margin: 0 auto;
	}

#imageContainer{
	padding: 10px;
	}

#loading{
	position: absolute;
	top: 40%;
	left: 0%;
	height: 25%;
	width: 100%;
	text-align: center;
	line-height: 0;
	}
#hoverNav{
	position: absolute;
	top: 0;
	left: 0;
	height: 100%;
	width: 100%;
	z-index: 10;
	}
#imageContainer>#hoverNav{ left: 0;}
#hoverNav a{ outline: none;}

#prevLink, #nextLink{
	width: 49%;
	height: 100%;
	background: transparent url(../images/blank.gif) no-repeat; /* Trick IE into showing hover */
	display: block;
	}
#prevLink { left: 0; float: left;}
#nextLink { right: 0; float: right;}
#prevLink:hover, #prevLink:visited:hover { background: url(../images/prevlabel.gif) left 15% no-repeat; }
#nextLink:hover, #nextLink:visited:hover { background: url(../images/nextlabel.gif) right 15% no-repeat; }


#imageDataContainer{
	font: 10px Verdana, Helvetica, sans-serif;
	background-color: #fff;
	margin: 0 auto;
	line-height: 1.4em;
	}

#imageData{
	padding:0 10px;
	}
#imageData #imageDetails{ width: 70%; float: left; text-align: left; }	
#imageData #caption{ font-weight: bold;	}
#imageData #numberDisplay{ display: block; clear: left; padding-bottom: 1.0em;	}			
#imageData #bottomNavClose{ width: 66px; float: right;  padding-bottom: 0.7em;	}	
		
#overlay{
	position: absolute;
	top: 0;
	left: 0;
	z-index: 90;
	width: 100%;
	height: 500px;
	background-color: #000000;
	filter:alpha(opacity=60);
	-moz-opacity: 0.6;
	opacity: 0.6;
	}
	

.clearfix:after {
	content: "."; 
	display: block; 
	height: 0; 
	clear: both; 
	visibility: hidden;
	}

* html>body .clearfix {
	display: inline-block; 
	width: 100%;
	}

* html .clearfix {
	/* Hides from IE-mac \*/
	height: 1%;
	/* End hide from IE-mac */
	}	
	


#prevLink {background: url(../lightbox/images/prevlabel.gif) left 15% no-repeat;}
#nextLink {background: url(../lightbox/images/nextlabel.gif) right 15% no-repeat;}
body
#divWG {text-align:center; font: 11px Verdana, Arial, Helvetica, sans-serif;}
#divWG img, #divWG table {border:none;}
#divWG a:link, #divWG a:visited {text-decoration:none;}
#divWG a:hover {color:red;text-decoration:underline;}
#tblThumbsLayout {text-align:left; margin: 0 auto;}
#tblGalleryName{margin-top:2px;}
#currentGalleryLocation {font-weight:bold;}
td#galleryNameCell {font-size: 18px; font-weight:bold; color:#606060; margin: 6px 6px 0 0;}
td#pagingCell {text-align:right; white-space:nowrap;}
.currentPage {font-weight: bold;}
td#pagingCell a, .currentPage {font-size: 12px; border:1px solid #ccc; vertical-align:middle; }
td#pagingCell a:hover, .currentPage {border: #666 1px solid; background-color:#fff; text-decoration:none;}
td.tdImg {border: 2px solid; border-color: #7d0207;
  text-align:center; filter:alpha(opacity=80); -moz-opacity: 0.8;	opacity: 0.8; vertical-align:middle;}
td.tdImg img {margin-top:0px;}
#pnCell {text-align:right;}
a.pn, a.pn:LINK,a.pn:VISITED {color: #606060; font: 9px arial, helvetica, sans-serif; text-decoration: none;}




