> Contact US>
<TABLE width="500px" border="0" align="center">
<TR>
<td>
<CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER>
The local adress :<BR>
- Romania<BR>
- Giurgiu<br>
- Bucharest Street Km. 59+420<br>
- Telephone 0246 210 165<br>
- Telephone 0735 085 507<br>
- Fax. 0246 210 284<br>
- E-mail adress: office@hotelrestaurantgiurgiu.ro<br>
- Web-Site: www.hotelrestaurantgiurgiu.ro<br>
- GPS Coordinates: <br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Latitude: 43.927777<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Longitude: 25.974818<br>
</td>
</tr>
<tr>
	<TD><br><br>
<TABLE border="0">
	<form action='sendmail.php' method='post'>
		<TR><TD>Name and Surname : </TD><TD><input type=text name=name ><BR></TD></TR>
		<TR><TD>E-mail adress : </TD><TD><input type=text name=email ><BR></TD></TR>
		<TR><TD>Telephone number : </TD><TD><input type=text name=phone ><BR></TD></TR>
		<TR><TD>Town / City : </TD><TD><input type=text name=oras ><BR></TD></TR>
		<tr><td class="form_field" valign='top' >Contain Letter :</td><td class="form_text"><textarea name="detalii" rows=6 cols=28 ></textarea>
		</td> 
	</tr> 
		<TR><TD colspan="2" ><CENTER>All fields are required !</CENTER></TD></TR>
		<TR><TD colspan="2" ><CENTER><input type=submit name=submit value='Send Letter'></CENTER></TD>
		</TR>
	</form>
</TABLE>
<center>Thank you for choosing to collaborate with us and we're waiting you!</center>
	</TD>
</TR>
</TABLE>