<?php
if(!isset($_GET['giurgiu'])) $_GET['giurgiu'] = '';
switch($_GET['giurgiu']) {
case '':
include "home.php";
break;
case 'hotel':
include "hotel.php";
break;
case 'restaurant':
include "restaurant.php";
break;
case 'rezervari':
include "rezervari.php";
break;
case 'contact':
include "contact.php";
break;
case 'revelion-2011':
include "revelion-2010.php";
break;
}
?>