> Restaurant >
<TABLE width="500px" border="0" align="center">
<TR>
<td><CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER></td>
</tr>
<tr>
	<TD>
Restaurant ANDALUZIA *** din Giurgiu dispune de urmatoarele :<br>
- Restaurant - capacitate de 380 de locuri<br>
- Terasa - capacitate de 45 de locuri<br>
- Micul dejun intre orele 07.30 - 10.00<br>
- Meniu traditional Romanesc<br>
- Restaurantul si terasa au urmatoarele dotari:<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Aer conditionat ( Restaurant )<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- TV cu cablu TV ( Restaurant si Terasa )<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;- Internet ( Restaurant si Terasa )<br>
Programul de functionare este 08.00 - 24.00<br>
	</TD>
</TR>
</TABLE>
<div id='divWG'>
<table id="tblThumbsLayout" cellpadding="0" cellspacing="5">
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-01.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant ***" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-01.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-02.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-02.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-03.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-03.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-04.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-04.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-05.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-05.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-06.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-06.JPG"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-07.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-07.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-08.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-08.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-09.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-09.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-10.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-10.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-11.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-11.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-12.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-12.JPG"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-13.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-13.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-14.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-14.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-15.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-15.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-16.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-16.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-17.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-17.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-18.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-18.JPG"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-19.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-19.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-20.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-20.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-21.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-21.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-22.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-22.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-23.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-23.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-24.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-24.JPG"></a><br></td>
</tr>
<tr>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-25.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-25.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-26.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-26.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-27.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-27.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-28.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-28.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-29.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-29.JPG"></a><br></td>
<td class='tdImg'><a href='img/galerie/restaurant/hotel-restaurant-giurgiu-30.JPG' rel='lightbox[gallery]'><img style="width: 80px" alt="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" title="Complex Andaluzia - Hotel - Restaurant *** - Pentru detalii folositi pagina de contact" src="img/galerie/restaurant/hotel-restaurant-giurgiu-30.JPG"></a><br></td>
</tr>
</table>
</div>

<CENTER>Va multumim ca ati ales sa colaborati cu noi si va asteptam!!!	</CENTER>