<table align="center">
<tr>
	<td>
		<p>
			<a href="http://validator.w3.org/check?uri=referer"><img
				src="http://www.w3.org/Icons/valid-html40"
				alt="Valid HTML 4.0 Transitional" height="31" width="88"></a>
		</p>
	</td>
	<td>
		<p>
			<a href="http://jigsaw.w3.org/css-validator/check/referer">
				<img style="border:0;width:88px;height:31px"
					src="http://jigsaw.w3.org/css-validator/images/vcss"
					alt="CSS valid!" >
			</a>
		</p>
	</td>
	<td>
		<p>
<a href="http://www.ro-cazare.info" target="_blank"><img src="http://www.ro-cazare.info/img/ro-cazare-baner-88x30.jpg" width="88" height="31" border="1" alt="Portal de PROMOVARE online locatii de cazare din Romania"></a> 
		</p>
	</td>
</tr>
</table>

<!-- Integrare logo Plecat.ro - START --> <div style='text-align:center; font-size: 8pt; font-family: Verdana;'> <div> <a href='http://www.plecat.ro' target='_blank' title='Plecat.ro - cazare ieftina in Romania - portal de informare turistica'> <img alt='Plecat.ro - Cazare ieftina in Romania' src='http://www.plecat.ro/STATIC_IMGS/__extlogos/plecat-ro-cazare-romania.png' border=0> </a> </div> <div><a href='http://www.plecat.ro' target='_blank' style='text-decoration:none; color: black;' title='Plecat.ro - cazare ieftina in Romania - portal de informare turistica'>www.plecat.ro</a><br></div> <div><a href='http://www.plecat.ro/cazare/romania/giurgiu/' target='_blank' style='text-decoration:none; color: black;' title='Plecat.ro - cazare Giurgiu - portal de informare turistic'> </a>
