<table class="menu" width="610px">
	<tr>
	<td>
	<a href="index.php"><img width="110px" height="60px" src="img/home.png" onmouseover="this.src='img/homeMouseOver.png';" onmouseout="this.src='img/home.png';" /></a>
	</td>
	<td>
	<a href="index.php?hotel-restaurant-giurgiu=hotel"><img width="110px"  height="60px" src="img/hotel.png" onmouseover="this.src='img/hotelMouseOver.png';" onmouseout="this.src='img/hotel.png';" /></a>
	</td>
	<td>
	<a href="index.php?hotel-restaurant-giurgiu=restaurant"><img width="110px"  height="60px" src="img/restaurant.png" onmouseover="this.src='img/restaurantMouseOver.png';" onmouseout="this.src='img/restaurant.png';" /></a>
	</td>
	<td>
	<a href="index.php?hotel-restaurant-giurgiu=rezervari"><img width="110px"  height="60px" src="img/rezervations.png" onmouseover="this.src='img/rezervationsMouseOver.png';" onmouseout="this.src='img/rezervations.png';" /></a>
	</td>
	<td>
	<a href="index.php?hotel-restaurant-giurgiu=contact"><img width="110px"  height="60px" src="img/contact.png" onmouseover="this.src='img/contactMouseOver.png';" onmouseout="this.src='img/contact.png';" /></a>
	</td>
		<td>
	<a href="http://www.hotelrestaurantgiurgiu.ro/index.php"><img style="width: 30px; height:20px; margin-bottom: 4px;" src="img/romania.gif" onmouseover="this.src='img/roMouseOver.png';" onmouseout="this.src='img/romania.gif';" alt="Romana"></a>
<br />
	<a href="http://www.hotelrestaurantgiurgiu.ro/en/index.php"><img style="width: 30px; height:20px; margin-top: 4px; margin-bottom: 4px;" src="img/england.gif" onmouseover="this.src='img/enMouseOver.png';" onmouseout="this.src='img/england.gif';" alt="English"></a>
	</td>
	</tr>
</table>