<?
####################################################################################
$to = "rezervari@hotelrestaurantgiurgiu.ro";

if(($_POST['nume']!="")&&($_POST['oras']!="")&&($_POST['email']!="")&&($_POST['telefon']!="")&&($_POST['rezervare']!="")&&($_POST['zile']!="")&&($_POST['persoane']!="")&&($_POST['camere']!="")){

	####### dont edit the code after this line! ###################################
	$subject = 'REZERVARE de la site';
	$headers = 'MIME-Version: 1.0'."\r\n";
	$headers .= 'Content-type: text/html; charset=iso-8859-1'."\r\n";
	$headers .= 'From: '.$_POST['email'].'>'."\r\n";	
//	$from = $_POST['email'];
	$content = "<B>Nume si prenume :</B>&nbsp;&nbsp;" . $_POST['nume'] 
	."<br><B>Oras :</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['oras'] 	
	."<br><B>Email :</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['email'] 
	."<br><B>Telefon :</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['telefon'] 
	."<br><B>Reverv de la data :</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['rezervare'] 
	."<br><B>Nr zile rezervate :</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['zile'] 
	."<br><B>Nr persoane :</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['persoane'] 
	."<br><B>Nr camere :</B>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;". $_POST['camere'] 
	."<BR><BR><B>Observatii :</B>&nbsp;&nbsp;" . $_POST['obs'] ;

	mail($to , $subject, $content, "From: $from \n" ."MIME-Version: 1.0\n" . "Content-type: text/html; charset=iso-8859-1");
	echo "<script>alert('Rezervare efectuata. Vom lua legatura cu dv in cel mai scurt timp pentru confirmare. Va multumim ca ati ales sa colaborati cu noi!')</script>";
}
else{
	echo "<script>alert('Email esuat ! Mesajul nu este complet !')</script>";
}
echo "<script>location.replace('index.php?giurgiu=rezervari')</script>";
?>