> Contact >
<TABLE width="500px" height="500px" border="0" align="center">
<TR>
<td>
<CENTER><H3>Complex ANDALUZIA<BR>Hotel - Restaurant<br>***</H3></CENTER>
Adresa postala:<BR>
- Romania<BR>
- Giurgiu<br>
- Str. Bucuresti Km. 59+420<br>
- Tel. 0246 210 165<br>
- Tel. 0735 085 507<br>
- Fax. 0246 210 284<br>
- Email: office@hotelrestaurantgiurgiu.ro<br>
- Site: www.hotelrestaurantgiurgiu.ro<br>
- Coordonate GPS: <br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Latitudine: 43.927777<br>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Longitudine: 25.974818<br>
</td>
</tr>
<tr>
	<TD><br><br>
	<form action='sendmail.php' method='post'>
<TABLE border="0">
		<TR><TD>Nume si prenume : </TD><TD><input type=text name="name" size="36" ><BR></TD></TR>
		<TR><TD>Adresa de email : </TD><TD><input type=text name="email" size="36" ><BR></TD></TR>
		<TR><TD>Nr telefon : </TD><TD><input type=text name="phone" size="36" ><BR></TD></TR>
		<TR><TD>Oras : </TD><TD><input type=text name="oras" size="36"><BR></TD></TR>
		<tr><td class="form_field" valign='top' >Continut email :</td><td class="form_text"><textarea name="detalii" rows=6 cols=28 ></textarea>
		</td> 
	</tr> 
		<TR><TD colspan="2" ><CENTER>Toate campurile sunt obligatorii !</CENTER></TD></TR>
		<TR><TD colspan="2" ><CENTER><input type=submit name="submit" value='Trimite Email'></CENTER></TD>
		</TR>
</TABLE>
	</form>
<CENTER>Va multumim ca ati ales sa colaborati cu noi si va asteptam!!!	</CENTER>
	</TD>
</TR>
</TABLE>