<script language="JavaScript1.1">
<!--

//Pixelating Image slideshow
//Copyright Dynamic Drive 2001
//Visit http://www.dynamicdrive.com for this script

//specify interval between slide (in mili seconds)
var slidespeed=3000
//specify images
var slideimages=new Array("img/banner/01.jpg","img/banner/02.jpg","img/banner/03.jpg","img/banner/04.jpg","img/banner/05.jpg","img/banner/06.jpg","img/banner/07.jpg","img/banner/08.jpg")
//specify corresponding links
var slidelinks=new Array("http://www.hotelrestaurantgiurgiu.ro","http://www.hotelrestaurantgiurgiu.ro","http://www.hotelrestaurantgiurgiu.ro")

var imageholder=new Array()
var ie55=window.createPopup
for (i=0;i<slideimages.length;i++){
imageholder[i]=new Image()
imageholder[i].src=slideimages[i]
}

function gotoshow(){
window.location=slidelinks[whichlink]
}

//-->
</script>